# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eyetask.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eyetask.proto',
  package='EyeTask',
  syntax='proto3',
  serialized_options=b'\n io.grpc.custom.neuromeka.EyeTaskB\014EyeTaskProtoP\001\242\002\004FDDO',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\reyetask.proto\x12\x07\x45yeTask\"(\n\x0cImageRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05\"\x90\x01\n\rImageResponse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\r\n\x05width\x18\x03 \x01(\x05\x12\x0e\n\x06height\x18\x04 \x01(\x05\x12\r\n\x05\x63olor\x18\x05 \x01(\x0c\x12\r\n\x05\x64\x65pth\x18\x06 \x01(\x0c\x12\x13\n\x0b\x64\x65pth_scale\x18\x07 \x01(\x02\x12\x13\n\x0b\x65rror_state\x18\x08 \x01(\x08\"\x15\n\x07Request\x12\n\n\x02id\x18\x01 \x01(\x05\"A\n\tClassList\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63lass_names\x18\x02 \x03(\t\x12\x13\n\x0b\x65rror_state\x18\x08 \x01(\x08\"L\n\rDetectRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03\x63ls\x18\x02 \x01(\x05\x12\x10\n\x08pose_cmd\x18\x03 \x03(\x02\x12\x10\n\x08robot_ip\x18\x04 \x01(\t\"*\n\x0fRetrieveRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03\x63ls\x18\x02 \x01(\x05\"\xca\x01\n\x0e\x44\x65tectResponse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x10\n\x08\x64\x65tected\x18\x02 \x01(\x08\x12\x0e\n\x06passed\x18\x03 \x01(\x08\x12\x0b\n\x03\x63ls\x18\x04 \x01(\x05\x12\x13\n\x0btar_ee_pose\x18\x05 \x03(\x02\x12\x15\n\rtar_tool_pose\x18\x06 \x03(\x02\x12\x14\n\x0ctar_obj_pose\x18\x07 \x03(\x02\x12\x10\n\x08tool_idx\x18\x08 \x01(\x05\x12\x13\n\x0b\x65rror_state\x18\t \x01(\x08\x12\x14\n\x0c\x65rror_module\x18\n \x01(\t2\xfc\x01\n\x07\x45yeTask\x12;\n\x08GetImage\x12\x15.EyeTask.ImageRequest\x1a\x16.EyeTask.ImageResponse\"\x00\x12\x36\n\x0cGetClassList\x12\x10.EyeTask.Request\x1a\x12.EyeTask.ClassList\"\x00\x12;\n\x06\x44\x65tect\x12\x16.EyeTask.DetectRequest\x1a\x17.EyeTask.DetectResponse\"\x00\x12?\n\x08Retrieve\x12\x18.EyeTask.RetrieveRequest\x1a\x17.EyeTask.DetectResponse\"\x00\x42\x39\n io.grpc.custom.neuromeka.EyeTaskB\x0c\x45yeTaskProtoP\x01\xa2\x02\x04\x46\x44\x44Ob\x06proto3'
)




_IMAGEREQUEST = _descriptor.Descriptor(
  name='ImageRequest',
  full_name='EyeTask.ImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EyeTask.ImageRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='EyeTask.ImageRequest.type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=66,
)


_IMAGERESPONSE = _descriptor.Descriptor(
  name='ImageResponse',
  full_name='EyeTask.ImageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EyeTask.ImageResponse.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='EyeTask.ImageResponse.type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='EyeTask.ImageResponse.width', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='EyeTask.ImageResponse.height', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='EyeTask.ImageResponse.color', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='EyeTask.ImageResponse.depth', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth_scale', full_name='EyeTask.ImageResponse.depth_scale', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_state', full_name='EyeTask.ImageResponse.error_state', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=213,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='EyeTask.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EyeTask.Request.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=236,
)


_CLASSLIST = _descriptor.Descriptor(
  name='ClassList',
  full_name='EyeTask.ClassList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EyeTask.ClassList.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_names', full_name='EyeTask.ClassList.class_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_state', full_name='EyeTask.ClassList.error_state', index=2,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=303,
)


_DETECTREQUEST = _descriptor.Descriptor(
  name='DetectRequest',
  full_name='EyeTask.DetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EyeTask.DetectRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cls', full_name='EyeTask.DetectRequest.cls', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_cmd', full_name='EyeTask.DetectRequest.pose_cmd', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='robot_ip', full_name='EyeTask.DetectRequest.robot_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=381,
)


_RETRIEVEREQUEST = _descriptor.Descriptor(
  name='RetrieveRequest',
  full_name='EyeTask.RetrieveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EyeTask.RetrieveRequest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cls', full_name='EyeTask.RetrieveRequest.cls', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=425,
)


_DETECTRESPONSE = _descriptor.Descriptor(
  name='DetectResponse',
  full_name='EyeTask.DetectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='EyeTask.DetectResponse.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='detected', full_name='EyeTask.DetectResponse.detected', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passed', full_name='EyeTask.DetectResponse.passed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cls', full_name='EyeTask.DetectResponse.cls', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tar_ee_pose', full_name='EyeTask.DetectResponse.tar_ee_pose', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tar_tool_pose', full_name='EyeTask.DetectResponse.tar_tool_pose', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tar_obj_pose', full_name='EyeTask.DetectResponse.tar_obj_pose', index=6,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tool_idx', full_name='EyeTask.DetectResponse.tool_idx', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_state', full_name='EyeTask.DetectResponse.error_state', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_module', full_name='EyeTask.DetectResponse.error_module', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=630,
)

DESCRIPTOR.message_types_by_name['ImageRequest'] = _IMAGEREQUEST
DESCRIPTOR.message_types_by_name['ImageResponse'] = _IMAGERESPONSE
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['ClassList'] = _CLASSLIST
DESCRIPTOR.message_types_by_name['DetectRequest'] = _DETECTREQUEST
DESCRIPTOR.message_types_by_name['RetrieveRequest'] = _RETRIEVEREQUEST
DESCRIPTOR.message_types_by_name['DetectResponse'] = _DETECTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ImageRequest = _reflection.GeneratedProtocolMessageType('ImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEREQUEST,
  '__module__' : 'eyetask_pb2'
  # @@protoc_insertion_point(class_scope:EyeTask.ImageRequest)
  })
_sym_db.RegisterMessage(ImageRequest)

ImageResponse = _reflection.GeneratedProtocolMessageType('ImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _IMAGERESPONSE,
  '__module__' : 'eyetask_pb2'
  # @@protoc_insertion_point(class_scope:EyeTask.ImageResponse)
  })
_sym_db.RegisterMessage(ImageResponse)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'eyetask_pb2'
  # @@protoc_insertion_point(class_scope:EyeTask.Request)
  })
_sym_db.RegisterMessage(Request)

ClassList = _reflection.GeneratedProtocolMessageType('ClassList', (_message.Message,), {
  'DESCRIPTOR' : _CLASSLIST,
  '__module__' : 'eyetask_pb2'
  # @@protoc_insertion_point(class_scope:EyeTask.ClassList)
  })
_sym_db.RegisterMessage(ClassList)

DetectRequest = _reflection.GeneratedProtocolMessageType('DetectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETECTREQUEST,
  '__module__' : 'eyetask_pb2'
  # @@protoc_insertion_point(class_scope:EyeTask.DetectRequest)
  })
_sym_db.RegisterMessage(DetectRequest)

RetrieveRequest = _reflection.GeneratedProtocolMessageType('RetrieveRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEREQUEST,
  '__module__' : 'eyetask_pb2'
  # @@protoc_insertion_point(class_scope:EyeTask.RetrieveRequest)
  })
_sym_db.RegisterMessage(RetrieveRequest)

DetectResponse = _reflection.GeneratedProtocolMessageType('DetectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DETECTRESPONSE,
  '__module__' : 'eyetask_pb2'
  # @@protoc_insertion_point(class_scope:EyeTask.DetectResponse)
  })
_sym_db.RegisterMessage(DetectResponse)


DESCRIPTOR._options = None

_EYETASK = _descriptor.ServiceDescriptor(
  name='EyeTask',
  full_name='EyeTask.EyeTask',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=633,
  serialized_end=885,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetImage',
    full_name='EyeTask.EyeTask.GetImage',
    index=0,
    containing_service=None,
    input_type=_IMAGEREQUEST,
    output_type=_IMAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetClassList',
    full_name='EyeTask.EyeTask.GetClassList',
    index=1,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_CLASSLIST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Detect',
    full_name='EyeTask.EyeTask.Detect',
    index=2,
    containing_service=None,
    input_type=_DETECTREQUEST,
    output_type=_DETECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Retrieve',
    full_name='EyeTask.EyeTask.Retrieve',
    index=3,
    containing_service=None,
    input_type=_RETRIEVEREQUEST,
    output_type=_DETECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EYETASK)

DESCRIPTOR.services_by_name['EyeTask'] = _EYETASK

# @@protoc_insertion_point(module_scope)



import os
import sys

current_dir = os.path.dirname(os.path.abspath(__file__))
parent_dir = os.path.abspath(os.path.join(current_dir, os.pardir))
sys.path.append(parent_dir)

from .indydcp3 import IndyDCP3
# from .indydcp2 import IndyDCP2
from .eye import IndyEye
from .ecat import EtherCAT
# from .moby import MobyDCP3
# from .motor import MotorClient

from .enums import *
__all__ = ['IndyDCP3', 'StopCategory', 'JointBaseType', 'TaskBaseType']





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='common_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x63ommon_msgs.proto\x12\x12Nrmk.IndyFramework\"\x07\n\x05\x45mpty\"\x17\n\x05State\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"\x17\n\x07IntMode\x12\x0c\n\x04mode\x18\x01 \x01(\x04\"=\n\x07StopCat\x12\x32\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32 .Nrmk.IndyFramework.StopCategory\"?\n\x08PauseCat\x12\x33\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32!.Nrmk.IndyFramework.PauseCategory\"%\n\x08Response\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x1a\n\x07Message\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t*\xc9\x02\n\x07OpState\x12\x11\n\rOP_SYSTEM_OFF\x10\x00\x12\x10\n\x0cOP_SYSTEM_ON\x10\x01\x12\x0e\n\nOP_VIOLATE\x10\x02\x12\x13\n\x0fOP_RECOVER_HARD\x10\x03\x12\x13\n\x0fOP_RECOVER_SOFT\x10\x04\x12\x0b\n\x07OP_IDLE\x10\x05\x12\r\n\tOP_MOVING\x10\x06\x12\x0f\n\x0bOP_TEACHING\x10\x07\x12\x10\n\x0cOP_COLLISION\x10\x08\x12\x13\n\x0fOP_STOP_AND_OFF\x10\t\x12\x11\n\rOP_COMPLIANCE\x10\n\x12\x14\n\x10OP_BRAKE_CONTROL\x10\x0b\x12\x13\n\x0fOP_SYSTEM_RESET\x10\x0c\x12\x14\n\x10OP_SYSTEM_SWITCH\x10\r\x12\x13\n\x0fOP_VIOLATE_HARD\x10\x0f\x12\x15\n\x11OP_MANUAL_RECOVER\x10\x10\x12\x0b\n\x07TELE_OP\x10\x11*\xb0\x01\n\tTrajState\x12\r\n\tTRAJ_NONE\x10\x00\x12\r\n\tTRAJ_INIT\x10\x01\x12\r\n\tTRAJ_CALC\x10\x02\x12\x11\n\rTRAJ_STAND_BY\x10\x03\x12\x0c\n\x08TRAJ_ACC\x10\x04\x12\x0f\n\x0bTRAJ_CRUISE\x10\x05\x12\x0c\n\x08TRAJ_DEC\x10\x06\x12\x13\n\x0fTRAJ_CANCELLING\x10\x07\x12\x11\n\rTRAJ_FINISHED\x10\x08\x12\x0e\n\nTRAJ_ERROR\x10\t*Z\n\rTrajCondition\x12\x10\n\x0cTRAJ_STARTED\x10\x00\x12\x11\n\rTRAJ_ACC_DONE\x10\x01\x12\x11\n\rTRAJ_CRZ_DONE\x10\x02\x12\x11\n\rTRAJ_DEC_DONE\x10\x03*F\n\x0cStopCategory\x12\x13\n\x0fIMMEDIATE_BRAKE\x10\x00\x12\x10\n\x0cSMOOTH_BRAKE\x10\x01\x12\x0f\n\x0bSMOOTH_ONLY\x10\x02*6\n\rPauseCategory\x12\x10\n\x0cSMOOTH_PAUSE\x10\x00\x12\x13\n\x0fIMMEDIATE_PAUSE\x10\x01*T\n\x0cProgramState\x12\r\n\tPROG_IDLE\x10\x00\x12\x10\n\x0cPROG_RUNNING\x10\x01\x12\x10\n\x0cPROG_PAUSING\x10\x02\x12\x11\n\rPROG_STOPPING\x10\x03*e\n\x13\x43ollisionPolicyType\x12\x12\n\x0e\x43OLL_NO_DETECT\x10\x00\x12\x0e\n\nCOLL_PAUSE\x10\x01\x12\x1b\n\x17\x43OLL_RESUME_AFTER_SLEEP\x10\x02\x12\r\n\tCOLL_STOP\x10\x03*:\n\x0bTuningSpace\x12\x0c\n\x08TUNE_ALL\x10\x00\x12\x0e\n\nTUNE_JOINT\x10\x01\x12\r\n\tTUNE_TASK\x10\x02*N\n\x0fTuningPrecision\x12\x11\n\rLOW_PRECISION\x10\x00\x12\x14\n\x10MIDDLE_PRECISION\x10\x01\x12\x12\n\x0eHIGH_PRECISION\x10\x02\x62\x06proto3'
)

_OPSTATE = _descriptor.EnumDescriptor(
  name='OpState',
  full_name='Nrmk.IndyFramework.OpState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OP_SYSTEM_OFF', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_SYSTEM_ON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_VIOLATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_RECOVER_HARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_RECOVER_SOFT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_IDLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_MOVING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_TEACHING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_COLLISION', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_STOP_AND_OFF', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_COMPLIANCE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_BRAKE_CONTROL', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_SYSTEM_RESET', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_SYSTEM_SWITCH', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_VIOLATE_HARD', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OP_MANUAL_RECOVER', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TELE_OP', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=296,
  serialized_end=625,
)
_sym_db.RegisterEnumDescriptor(_OPSTATE)

OpState = enum_type_wrapper.EnumTypeWrapper(_OPSTATE)
_TRAJSTATE = _descriptor.EnumDescriptor(
  name='TrajState',
  full_name='Nrmk.IndyFramework.TrajState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRAJ_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_INIT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_CALC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_STAND_BY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_ACC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_CRUISE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_DEC', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_CANCELLING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_FINISHED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_ERROR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=628,
  serialized_end=804,
)
_sym_db.RegisterEnumDescriptor(_TRAJSTATE)

TrajState = enum_type_wrapper.EnumTypeWrapper(_TRAJSTATE)
_TRAJCONDITION = _descriptor.EnumDescriptor(
  name='TrajCondition',
  full_name='Nrmk.IndyFramework.TrajCondition',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRAJ_STARTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_ACC_DONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_CRZ_DONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRAJ_DEC_DONE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=806,
  serialized_end=896,
)
_sym_db.RegisterEnumDescriptor(_TRAJCONDITION)

TrajCondition = enum_type_wrapper.EnumTypeWrapper(_TRAJCONDITION)
_STOPCATEGORY = _descriptor.EnumDescriptor(
  name='StopCategory',
  full_name='Nrmk.IndyFramework.StopCategory',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMMEDIATE_BRAKE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOOTH_BRAKE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMOOTH_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=898,
  serialized_end=968,
)
_sym_db.RegisterEnumDescriptor(_STOPCATEGORY)

StopCategory = enum_type_wrapper.EnumTypeWrapper(_STOPCATEGORY)
_PAUSECATEGORY = _descriptor.EnumDescriptor(
  name='PauseCategory',
  full_name='Nrmk.IndyFramework.PauseCategory',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMOOTH_PAUSE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMMEDIATE_PAUSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=970,
  serialized_end=1024,
)
_sym_db.RegisterEnumDescriptor(_PAUSECATEGORY)

PauseCategory = enum_type_wrapper.EnumTypeWrapper(_PAUSECATEGORY)
_PROGRAMSTATE = _descriptor.EnumDescriptor(
  name='ProgramState',
  full_name='Nrmk.IndyFramework.ProgramState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROG_IDLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROG_RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROG_PAUSING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROG_STOPPING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1026,
  serialized_end=1110,
)
_sym_db.RegisterEnumDescriptor(_PROGRAMSTATE)

ProgramState = enum_type_wrapper.EnumTypeWrapper(_PROGRAMSTATE)
_COLLISIONPOLICYTYPE = _descriptor.EnumDescriptor(
  name='CollisionPolicyType',
  full_name='Nrmk.IndyFramework.CollisionPolicyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COLL_NO_DETECT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLL_PAUSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLL_RESUME_AFTER_SLEEP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLL_STOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1112,
  serialized_end=1213,
)
_sym_db.RegisterEnumDescriptor(_COLLISIONPOLICYTYPE)

CollisionPolicyType = enum_type_wrapper.EnumTypeWrapper(_COLLISIONPOLICYTYPE)
_TUNINGSPACE = _descriptor.EnumDescriptor(
  name='TuningSpace',
  full_name='Nrmk.IndyFramework.TuningSpace',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TUNE_ALL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUNE_JOINT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TUNE_TASK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1215,
  serialized_end=1273,
)
_sym_db.RegisterEnumDescriptor(_TUNINGSPACE)

TuningSpace = enum_type_wrapper.EnumTypeWrapper(_TUNINGSPACE)
_TUNINGPRECISION = _descriptor.EnumDescriptor(
  name='TuningPrecision',
  full_name='Nrmk.IndyFramework.TuningPrecision',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW_PRECISION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIDDLE_PRECISION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH_PRECISION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1275,
  serialized_end=1353,
)
_sym_db.RegisterEnumDescriptor(_TUNINGPRECISION)

TuningPrecision = enum_type_wrapper.EnumTypeWrapper(_TUNINGPRECISION)
OP_SYSTEM_OFF = 0
OP_SYSTEM_ON = 1
OP_VIOLATE = 2
OP_RECOVER_HARD = 3
OP_RECOVER_SOFT = 4
OP_IDLE = 5
OP_MOVING = 6
OP_TEACHING = 7
OP_COLLISION = 8
OP_STOP_AND_OFF = 9
OP_COMPLIANCE = 10
OP_BRAKE_CONTROL = 11
OP_SYSTEM_RESET = 12
OP_SYSTEM_SWITCH = 13
OP_VIOLATE_HARD = 15
OP_MANUAL_RECOVER = 16
TELE_OP = 17
TRAJ_NONE = 0
TRAJ_INIT = 1
TRAJ_CALC = 2
TRAJ_STAND_BY = 3
TRAJ_ACC = 4
TRAJ_CRUISE = 5
TRAJ_DEC = 6
TRAJ_CANCELLING = 7
TRAJ_FINISHED = 8
TRAJ_ERROR = 9
TRAJ_STARTED = 0
TRAJ_ACC_DONE = 1
TRAJ_CRZ_DONE = 2
TRAJ_DEC_DONE = 3
IMMEDIATE_BRAKE = 0
SMOOTH_BRAKE = 1
SMOOTH_ONLY = 2
SMOOTH_PAUSE = 0
IMMEDIATE_PAUSE = 1
PROG_IDLE = 0
PROG_RUNNING = 1
PROG_PAUSING = 2
PROG_STOPPING = 3
COLL_NO_DETECT = 0
COLL_PAUSE = 1
COLL_RESUME_AFTER_SLEEP = 2
COLL_STOP = 3
TUNE_ALL = 0
TUNE_JOINT = 1
TUNE_TASK = 2
LOW_PRECISION = 0
MIDDLE_PRECISION = 1
HIGH_PRECISION = 2



_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='Nrmk.IndyFramework.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=48,
)


_STATE = _descriptor.Descriptor(
  name='State',
  full_name='Nrmk.IndyFramework.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='Nrmk.IndyFramework.State.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=50,
  serialized_end=73,
)


_INTMODE = _descriptor.Descriptor(
  name='IntMode',
  full_name='Nrmk.IndyFramework.IntMode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='Nrmk.IndyFramework.IntMode.mode', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=98,
)


_STOPCAT = _descriptor.Descriptor(
  name='StopCat',
  full_name='Nrmk.IndyFramework.StopCat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='Nrmk.IndyFramework.StopCat.category', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=161,
)


_PAUSECAT = _descriptor.Descriptor(
  name='PauseCat',
  full_name='Nrmk.IndyFramework.PauseCat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='Nrmk.IndyFramework.PauseCat.category', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=226,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='Nrmk.IndyFramework.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Nrmk.IndyFramework.Response.code', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='Nrmk.IndyFramework.Response.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=265,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='Nrmk.IndyFramework.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='Nrmk.IndyFramework.Message.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=267,
  serialized_end=293,
)

_STOPCAT.fields_by_name['category'].enum_type = _STOPCATEGORY
_PAUSECAT.fields_by_name['category'].enum_type = _PAUSECATEGORY
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['State'] = _STATE
DESCRIPTOR.message_types_by_name['IntMode'] = _INTMODE
DESCRIPTOR.message_types_by_name['StopCat'] = _STOPCAT
DESCRIPTOR.message_types_by_name['PauseCat'] = _PAUSECAT
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.enum_types_by_name['OpState'] = _OPSTATE
DESCRIPTOR.enum_types_by_name['TrajState'] = _TRAJSTATE
DESCRIPTOR.enum_types_by_name['TrajCondition'] = _TRAJCONDITION
DESCRIPTOR.enum_types_by_name['StopCategory'] = _STOPCATEGORY
DESCRIPTOR.enum_types_by_name['PauseCategory'] = _PAUSECATEGORY
DESCRIPTOR.enum_types_by_name['ProgramState'] = _PROGRAMSTATE
DESCRIPTOR.enum_types_by_name['CollisionPolicyType'] = _COLLISIONPOLICYTYPE
DESCRIPTOR.enum_types_by_name['TuningSpace'] = _TUNINGSPACE
DESCRIPTOR.enum_types_by_name['TuningPrecision'] = _TUNINGPRECISION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'common_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Empty)
  })
_sym_db.RegisterMessage(Empty)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
  'DESCRIPTOR' : _STATE,
  '__module__' : 'common_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.State)
  })
_sym_db.RegisterMessage(State)

IntMode = _reflection.GeneratedProtocolMessageType('IntMode', (_message.Message,), {
  'DESCRIPTOR' : _INTMODE,
  '__module__' : 'common_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IntMode)
  })
_sym_db.RegisterMessage(IntMode)

StopCat = _reflection.GeneratedProtocolMessageType('StopCat', (_message.Message,), {
  'DESCRIPTOR' : _STOPCAT,
  '__module__' : 'common_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.StopCat)
  })
_sym_db.RegisterMessage(StopCat)

PauseCat = _reflection.GeneratedProtocolMessageType('PauseCat', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECAT,
  '__module__' : 'common_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.PauseCat)
  })
_sym_db.RegisterMessage(PauseCat)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'common_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Response)
  })
_sym_db.RegisterMessage(Response)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'common_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.Message)
  })
_sym_db.RegisterMessage(Message)


# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import common_msgs_pb2 as common__msgs__pb2
import rtde_msgs_pb2 as rtde__msgs__pb2


class RTDataExchangeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMotionData = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/GetMotionData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=rtde__msgs__pb2.MotionData.FromString,
                )
        self.GetControlData = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/GetControlData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=rtde__msgs__pb2.ControlData.FromString,
                )
        self.GetControlState = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/GetControlState',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=rtde__msgs__pb2.ControlData2.FromString,
                )
        self.GetIOData = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/GetIOData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=rtde__msgs__pb2.IOData.FromString,
                )
        self.GetServoData = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/GetServoData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=rtde__msgs__pb2.ServoData.FromString,
                )
        self.GetViolationData = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/GetViolationData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=rtde__msgs__pb2.ViolationData.FromString,
                )
        self.GetProgramData = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/GetProgramData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=rtde__msgs__pb2.ProgramData.FromString,
                )
        self.TestFunction = channel.unary_unary(
                '/Nrmk.IndyFramework.RTDataExchange/TestFunction',
                request_serializer=rtde__msgs__pb2.TestRequest.SerializeToString,
                response_deserializer=rtde__msgs__pb2.TestResponse.FromString,
                )


class RTDataExchangeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetMotionData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetControlData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetControlState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIOData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServoData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetViolationData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProgramData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestFunction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RTDataExchangeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMotionData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMotionData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=rtde__msgs__pb2.MotionData.SerializeToString,
            ),
            'GetControlData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetControlData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=rtde__msgs__pb2.ControlData.SerializeToString,
            ),
            'GetControlState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetControlState,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=rtde__msgs__pb2.ControlData2.SerializeToString,
            ),
            'GetIOData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIOData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=rtde__msgs__pb2.IOData.SerializeToString,
            ),
            'GetServoData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServoData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=rtde__msgs__pb2.ServoData.SerializeToString,
            ),
            'GetViolationData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetViolationData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=rtde__msgs__pb2.ViolationData.SerializeToString,
            ),
            'GetProgramData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProgramData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=rtde__msgs__pb2.ProgramData.SerializeToString,
            ),
            'TestFunction': grpc.unary_unary_rpc_method_handler(
                    servicer.TestFunction,
                    request_deserializer=rtde__msgs__pb2.TestRequest.FromString,
                    response_serializer=rtde__msgs__pb2.TestResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Nrmk.IndyFramework.RTDataExchange', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RTDataExchange(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetMotionData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/GetMotionData',
            common__msgs__pb2.Empty.SerializeToString,
            rtde__msgs__pb2.MotionData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetControlData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/GetControlData',
            common__msgs__pb2.Empty.SerializeToString,
            rtde__msgs__pb2.ControlData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetControlState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/GetControlState',
            common__msgs__pb2.Empty.SerializeToString,
            rtde__msgs__pb2.ControlData2.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIOData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/GetIOData',
            common__msgs__pb2.Empty.SerializeToString,
            rtde__msgs__pb2.IOData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServoData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/GetServoData',
            common__msgs__pb2.Empty.SerializeToString,
            rtde__msgs__pb2.ServoData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetViolationData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/GetViolationData',
            common__msgs__pb2.Empty.SerializeToString,
            rtde__msgs__pb2.ViolationData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProgramData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/GetProgramData',
            common__msgs__pb2.Empty.SerializeToString,
            rtde__msgs__pb2.ProgramData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestFunction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.RTDataExchange/TestFunction',
            rtde__msgs__pb2.TestRequest.SerializeToString,
            rtde__msgs__pb2.TestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
